@@ -1,6 +1,6 @@
 use strum_macros::{Display, EnumString, EnumIter};
 
-#[derive(Debug, Hash, Eq, PartialEq, Display, EnumString, EnumIter, Clone)]
+#[derive(Debug, Hash, Eq, PartialEq, Display, EnumString, EnumIter, Clone, Copy)]
 pub enum Class {
     Scout,
     Soldier,
