@@ -1,8 +1,9 @@
 use strum_macros::{Display, EnumString, EnumIter};
 use num_enum::{TryFromPrimitive, IntoPrimitive};
 use serde_repr::{Serialize_repr, Deserialize_repr};
+use crate::Attributes;
 
-#[derive(Serialize_repr, Deserialize_repr, Debug, Hash, Eq, PartialEq, Display, EnumString, EnumIter, TryFromPrimitive, IntoPrimitive, Clone)]
+#[derive(Serialize_repr, Deserialize_repr, Debug, Hash, Eq, PartialEq, Display, EnumString, EnumIter, TryFromPrimitive, IntoPrimitive, Clone, Copy)]
 #[repr(u8)]
 pub enum StrangePart {
     #[strum(serialize = "Scouts Killed")]
@@ -114,7 +115,7 @@ pub enum StrangePart {
 impl StrangePart {
     
     pub fn score_type(&self) -> u8 {
-        u8::from(self.clone())
+        u8::from(*self)
     }
     
     pub fn defindex(&self) -> u32 {
@@ -175,6 +176,10 @@ impl StrangePart {
     }
 }
 
+impl Attributes for StrangePart {
+    const DEFINDEX: &'static [u32] = &[380, 382, 384];
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
